@@ -60,13 +60,9 @@ class anotationGen:
         if model_output_sparse:
             pass
             # TODO : do simple mapping
-
-
         self.synID_to_desc ={
             k: CS_label_names[v-1] for k,v in self.synID_2_csID.items()
         }
-        print(self.synID_to_desc)
-        pprint(self.color_to_synID)
         return
 
 
@@ -133,9 +129,7 @@ class anotationGen:
     # Input is the output of SS Model ( numpy array object )
     # -----------------------------------------
     def gen_SynLabel(self, data_path=None, default_value = 0 ):
-        print('[generating synthetic label]', data_path)
         data = np.load(data_path)
-        print(np.min(data), np.max(data), np.unique(data))
         def _replace(val):
             if val in self.csID_2_synID.keys():
                 return self.csID_2_synID[val]
